#
# spec file for package varnish
#
# Copyright (c) 2011 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

# norootforbuild


Name:           varnish
Version:        2.1.3
Release:        3.4.1
#
License:        BSD
Group:          Productivity/Networking/Web/Proxy
#
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  libxslt ncurses-devel pcre-devel pkg-config
Prereq(post):	%_sbindir/useradd %_sbindir/groupadd
%if 0%{?suse_version}
Recommends:     logrotate
%endif
%define pkg_home     %_localstatedir/lib/%name
%define pkg_logdir   %_localstatedir/log/%name
%define pkg_cachedir %_localstatedir/cache/%name
#
Url:            http://www.varnish-cache.org/
Source0:        http://downloads.sourceforge.net/varnish/varnish-%version.tar.gz
#         http://downloads.sourceforge.net/varnish/varnish-%version.tar.bz2
Source2:        varnish.init
Source3:        varnish.sysconfig
Source4:        vcl.conf
Source5:        varnish.logrotate
#
Summary:        Varnish is a high-performance HTTP accelerator

%description
Varnish is an HTTP accelerator. An HTTP accelerator (often called Reverse
Proxy) is an application that stores (caches) documents that have been
requested over the HTTP protocol.

Based on certain criteria the next client requesting the document is either
given the cached document, or a "fresh" document requested from a backend
server. The purpose of this is to minimize the requests going to the backend
server(s) by serving the same document to potentially many users.


Authors:
--------
    Poul-Henning Kamp <phk@phk.freebsd.dk>

%define library_name libvarnish1

%package -n %library_name

Group:          Productivity/Networking/Web/Proxy
#
Summary:        Shared libraries for Varnish

%description -n %library_name
Varnish is an HTTP accelerator. An HTTP accelerator (often called Reverse
Proxy) is an application that stores (caches) documents that have been
requested over the HTTP protocol.

Based on certain criteria the next client requesting the document is either
given the cached document, or a "fresh" document requested from a backend
server. The purpose of this is to minimize the requests going to the backend
server(s) by serving the same document to potentially many users.


This package holds the shared libraries for varnish.


Authors:
--------
    Poul-Henning Kamp <phk@phk.freebsd.dk>


%package devel
License:        BSD
Group:          Development/Libraries/C and C++
Requires:       %name = %version
#
Summary:        Development files for Varnish

%description devel
Varnish is an HTTP accelerator. An HTTP accelerator (often called Reverse
Proxy) is an application that stores (caches) documents that have been
requested over the HTTP protocol.

Based on certain criteria the next client requesting the document is either
given the cached document, or a "fresh" document requested from a backend
server. The purpose of this is to minimize the requests going to the backend
server(s) by serving the same document to potentially many users.


This package holds the development files for varnish.


Authors:
--------
    Poul-Henning Kamp <phk@phk.freebsd.dk>


%prep
%setup -q

%build
%if 0%{?suse_version} > 1000
export CFLAGS="%optflags -fstack-protector"
%endif
%configure --disable-static --localstatedir=%_localstatedir/cache/ \
           --enable-debugging-symbols \
           --enable-developer-warnings
make %{?_smp_mflags}

%install
%makeinstall
find %buildroot -ls
# There is no use for them to normal users
mv %buildroot/%_bindir/* %buildroot/%_sbindir/
#
# remove unneeded files
# libvarnish.la has -lrt as dependency lib
#rm -fv %buildroot%_libdir/*.la
#
##missing directories
install -d -m 0755 %buildroot{%pkg_logdir,%pkg_home}
install -D -m 0644 %{S:5} %buildroot%_sysconfdir/logrotate.d/varnish
#
##init scripts
install -D -m 0644 %{S:3} %buildroot/var/adm/fillup-templates/sysconfig.%name
install -D -m 0755 %{S:2} %buildroot%_sysconfdir/init.d/%name
ln -s -f %_sysconfdir/init.d/%name %buildroot%_sbindir/rc%name
#
##config files
install -D -m 0644 %{S:4} %buildroot%_sysconfdir/%name/vcl.conf
install -D -m 0644 %{S:4} %buildroot%_sysconfdir/%name/vcl.conf.example

find "%buildroot" -type f -name "*.la" -delete
mkdir -p "%buildroot/%_localstatedir/log/varnish"

%pre
%_bindir/getent group varnish >/dev/null || \
	%_sbindir/groupadd -r varnish || :
%_bindir/getent passwd varnish >/dev/null || \
	%_sbindir/useradd -g varnish -s /bin/false -r -c "user for Varnish" \
		-d %pkg_home varnish || :
%if 0%{?suse_version}

%post
%fillup_and_insserv %name

%preun
%stop_on_removal %name

%postun
%restart_on_update %name
%insserv_cleanup
%else
# how to do the same for RH/mandriva?
%endif

%post   -n %library_name -p /sbin/ldconfig

%postun -n %library_name -p /sbin/ldconfig

%files
%defattr(-,root,root,-)
%if 0%{?suse_version}
%_sbindir/rc%name
/var/adm/fillup-templates/sysconfig.%name
%else
%config(noreplace) %_sysconfdir/sysconfig/%name
%endif
%config(noreplace) %_sysconfdir/init.d/%name
#
%dir %attr(750,root,varnish) %_sysconfdir/%name/
%config(noreplace) %attr(640,root,varnish) %_sysconfdir/%name/vcl.conf
%config            %attr(640,root,varnish) %_sysconfdir/%name/vcl.conf.example
%config(noreplace) %attr(640,root,varnish) %_sysconfdir/%name/default.vcl
#
%_sbindir/*
%doc %_mandir/*/*
%doc ChangeLog LICENSE README
%if ! 0%{?suse_version}
%doc redhat/README.redhat
%endif
%dir %attr(750,varnish,varnish) %pkg_home
%dir %attr(750,varnish,varnish) %pkg_cachedir
%config(noreplace) %_sysconfdir/logrotate.d/varnish
%dir %attr(750,varnish,varnish) %_localstatedir/log/varnish

%files -n %library_name
%defattr(-,root,root,-)
%_libdir/*.so.*

%files devel
%defattr(-,root,root,-)
%_includedir/varnish/
%_libdir/pkgconfig/*
%_libdir/*.so

%changelog
* Sun Apr  3 2011 jengelh@medozas.de
- Fix security-problematic ownership of /etc/varnish files
  (bnc#678811)
- Run spec-beautifier over it
- Replace default shipped vcl.conf by something working
- Run as varnish user
- Start varnishlog together with varnishd
- Properly use PID files in init script
* Sat Oct  9 2010 jengelh@medozas.de
- Create and package /var/log/varnish
* Thu Aug  5 2010 jengelh@medozas.de
- Update to new upstream release: 2.1.3
  * fixed an off-by-one error in the ESI handling causing includes to
  fail a large part of the time.
  * Avoid triggering an assert if the other end closes the connection
  while we are lingering and waiting for another request from them.
  * Make it possible to specify the per-thread stack size. This might
  be useful on 32 bit systems with their limited address space.
  * Persistent storage is now experimentally supported using the
  persistent stevedore. It has the same command line arguments as
  the file stevedore.
  * The regular expression engine is now PCRE instead of POSIX
  regular expressions.
  * Add a new hashing method called critbit. This autoscales and
  should work better on large object workloads than the classic
  hash. Critbit has been made the default hash algorithm.
  * Add support for authenticating CLI connections.
  * Add hash director that chooses which backend to use depending on
  req.hash.
  * Add client director that chooses which backend to use depending
  on the client's IP address. Note that this ignores the
  X-Forwarded-For header.
  * Add a timestamp to bans, so you can know how old they are.
  * Varnish can now connect its CLI to a remote instance when
  starting up, rather than just being connected to.
  * It is no longer needed to specify the maximum number of HTTP
  headers to allow from backends. This is now a run-time parameter.
  * HEAD requests would be converted to GET requests too early, which
  affected pass and pipe. This has been fixed.
  * Add experimental support for the Range header. This has to be
  enabled using the parameter http_range_support.
- Add PreReqs for %%post
- Run %%setup quietly
- Remove unneeded .la files from installation - libraries are in
  a standard directory already
- Avoid use of bash-specific &>/dev/null during %%post
- Refine file lists
- Remove old changelog from .spec - changelog is in .changes
* Tue Dec 15 2009 jg@internetx.de
- update 2.0.5
* Fri Apr  3 2009 mrueckert@suse.de
- update to 2.0.4
* Tue Mar 10 2009 mrueckert@suse.de
- update to 2.0.3
* Wed Jul 25 2007 mrueckert@suse.de
- updated to 1.1
* Tue Feb 20 2007 mrueckert@suse.de
- update to version 1.0.3
  Consistency issues with statistics and backend parameters were
  fixed. Parsing of -w command-line options was fixed. A
  short-lived DNS cache was added to avoid thrashing DNS servers
  when the backend fails.
* Sat Dec  2 2006 mrueckert@suse.de
- fixing build on sles9
- added files from the official rh4 rpm:
  o init scripts for non suse distros
  o the default configs for all distros
- added init/sysconfig script for suse.
- we create a user now. Remaining TODO item: how to run varnish as
  non root user on port 80?
* Sun Nov 19 2006 mrueckert@suse.de
- update to 1.0.2
